pub enum BenchmarkCommand {
Single {
options: BenchmarkOptions,
},
Multi {
options: BenchmarkOptions,
processes: usize,
faucet: String,
client_state_dir: Option<String>,
delay_between_processes: u64,
cross_wallet_transfers: bool,
},
}Expand description
The benchmarking subcommands.
Variants
Single
Start a single benchmark process, maintaining a given TPS.
Fields

options: BenchmarkOptionsThe benchmark options.
Multi
Run multiple benchmark processes in parallel.
Fields

options: BenchmarkOptionsThe benchmark options.

client_state_dir: Option<String>If specified, a directory with a random name will be created in this directory, and the client state will be stored there. If not specified, a temporary directory will be used for each client.
Implementations
Sourceimpl BenchmarkCommand
impl BenchmarkCommand
Sourcepub fn transactions_per_block(&self) -> usize
pub fn transactions_per_block(&self) -> usize
Returns the number of transactions per block configured for this benchmark.