pub enum NetCommand {
Up {Show 18 fields
other_initial_chains: u32,
initial_amount: u128,
validators: usize,
shards: usize,
policy_config: ResourceControlPolicyConfig,
cross_chain_config: CrossChainConfig,
testing_prng_seed: Option<u64>,
path: Option<String>,
external_protocol: String,
with_faucet: bool,
faucet_chain: Option<u32>,
faucet_port: NonZeroU16,
faucet_amount: Amount,
with_block_exporter: bool,
num_block_exporters: usize,
exporter_address: String,
exporter_port: NonZeroU16,
http_request_allow_list: Option<Vec<String>>,
},
Helper,
}Expand description
The subcommands for managing a local Linera network.
Variants
Up
Start a Local Linera Network
Fields
other_initial_chains: u32The number of initial “root” chains created in the genesis config on top of the default “admin” chain. All initial chains belong to the first “admin” wallet. It is recommended to use at least one other initial chain for the faucet.
initial_amount: u128The initial amount of native tokens credited in the initial “root” chains, including the default “admin” chain.
policy_config: ResourceControlPolicyConfigConfigure the resource control policy (notably fees) according to pre-defined settings.
cross_chain_config: CrossChainConfigThe configuration for cross-chain messages.
testing_prng_seed: Option<u64>Force this wallet to generate keys using a PRNG and a given seed. USE FOR TESTING ONLY.
path: Option<String>Run with a specific path where the wallet and validator input files are. If none, then a temporary directory is created.
with_faucet: boolIf present, a faucet is started using the chain provided by –faucet-chain, or the first non-admin chain if not provided.
faucet_chain: Option<u32>When using –with-faucet, this specifies the chain on which the faucet will be started.
If this is n, the n-th non-admin chain (lexicographically) in the wallet is selected.
faucet_port: NonZeroU16The port on which to run the faucet server
exporter_port: NonZeroU16The port on which to run the block exporter.
Helper
Print a bash helper script to make linera net up easier to use. The script is
meant to be installed in ~/.bash_profile or sourced when needed.