pub enum ProjectCommand {
New {
name: String,
linera_root: Option<PathBuf>,
},
Test {
path: Option<PathBuf>,
},
PublishAndCreate {
path: Option<PathBuf>,
name: Option<String>,
publisher: Option<ChainId>,
vm_runtime: VmRuntime,
json_parameters: Option<String>,
json_parameters_path: Option<PathBuf>,
json_argument: Option<String>,
json_argument_path: Option<PathBuf>,
required_application_ids: Option<Vec<ApplicationId>>,
},
}Expand description
The subcommands for managing Linera projects.
Variants
New
Create a new Linera project.
Fields
Test
Test a Linera project.
Equivalent to running cargo test with the appropriate test runner.
PublishAndCreate
Build and publish a Linera project.
Fields
path: Option<PathBuf>The path of the root of the Linera project. Defaults to current working directory if unspecified.
name: Option<String>Specify the name of the Linera project.
This is used to locate the generated bytecode files. The generated bytecode files should
be of the form <name>_{contract,service}.wasm.
Defaults to the package name in Cargo.toml, with dashes replaced by underscores.
publisher: Option<ChainId>An optional chain ID to publish the module. The default chain of the wallet is used otherwise.
required_application_ids: Option<Vec<ApplicationId>>The list of required dependencies of application, if any.