pub enum WalletCommand {
Show {
chain_id: Option<ChainId>,
short: bool,
owned: bool,
},
SetDefault {
chain_id: ChainId,
},
Init {
genesis_config_path: Option<PathBuf>,
faucet: Option<String>,
testing_prng_seed: Option<u64>,
},
RequestChain {
faucet: String,
set_default: bool,
},
ExportGenesis {
output: PathBuf,
faucet: Option<String>,
},
FollowChain {
chain_id: ChainId,
sync: bool,
},
ForgetKeys {
chain_id: ChainId,
},
ForgetChain {
chain_id: ChainId,
},
}Expand description
The subcommands for managing the wallet.
Variants
Show
Show the contents of the wallet.
Fields
SetDefault
Change the wallet default chain.
Init
Initialize a wallet from the genesis configuration.
Fields
RequestChain
Request a new chain from a faucet and add it to the wallet.
Fields
ExportGenesis
Export the genesis configuration to a JSON file.
By default, exports the genesis config from the current wallet. Alternatively,
use --faucet to retrieve the genesis config directly from a faucet URL.
Fields
FollowChain
Add a new followed chain (i.e. a chain without keypair) to the wallet.
Fields
ForgetKeys
Forgets the specified chain’s keys. The chain will still be followed by the wallet.
ForgetChain
Forgets the specified chain, including the associated key pair.