pub struct QueryBlock { /* private fields */ }Expand description
Query a single validator for a block at a particular chain and height.
Connects to a validator at the specified network address and queries its view of the blockchain.