pub struct Sync { /* private fields */ }Expand description
Synchronize chain state to a validator.
Pushes the current chain state from local storage to a validator node, ensuring the validator has up-to-date information about specified chains.