pub struct NodeService { /* private fields */ }Expand description
A running node service.
Implementations
Sourceimpl NodeService
impl NodeService
Sourcepub async fn terminate(self) -> Result<()>
pub async fn terminate(self) -> Result<()>
Terminates the node service by killing its child process.
Sourcepub fn ensure_is_running(&mut self) -> Result<()>
pub fn ensure_is_running(&mut self) -> Result<()>
Checks that the node service child process is still running.
Sourcepub async fn process_inbox(&self, chain_id: &ChainId) -> Result<Vec<CryptoHash>>
pub async fn process_inbox(&self, chain_id: &ChainId) -> Result<Vec<CryptoHash>>
Issues a processInbox GraphQL mutation and returns the hashes of the created blocks.
Sourcepub async fn sync(&self, chain_id: &ChainId) -> Result<u64>
pub async fn sync(&self, chain_id: &ChainId) -> Result<u64>
Issues a sync GraphQL mutation for the given chain and returns the new block height.
Sourcepub async fn transfer(
&self,
chain_id: ChainId,
owner: AccountOwner,
recipient: Account,
amount: Amount,
) -> Result<CryptoHash>
pub async fn transfer( &self, chain_id: ChainId, owner: AccountOwner, recipient: Account, amount: Amount, ) -> Result<CryptoHash>
Issues a transfer GraphQL mutation and returns the resulting block hash.
Sourcepub async fn balance(&self, account: &Account) -> Result<Amount>
pub async fn balance(&self, account: &Account) -> Result<Amount>
Queries the balance of the given account via GraphQL.
Sourcepub fn make_application<A: ContractAbi>(
&self,
chain_id: &ChainId,
application_id: &ApplicationId<A>,
) -> Result<ApplicationWrapper<A>>
pub fn make_application<A: ContractAbi>( &self, chain_id: &ChainId, application_id: &ApplicationId<A>, ) -> Result<ApplicationWrapper<A>>
Returns an ApplicationWrapper for querying the given application on this node service.
Sourcepub async fn publish_data_blob(
&self,
chain_id: &ChainId,
bytes: Vec<u8>,
) -> Result<CryptoHash>
pub async fn publish_data_blob( &self, chain_id: &ChainId, bytes: Vec<u8>, ) -> Result<CryptoHash>
Issues a publishDataBlob GraphQL mutation and returns the blob’s hash.
Sourcepub async fn publish_module<Abi, Parameters, InstantiationArgument>(
&self,
chain_id: &ChainId,
contract: PathBuf,
service: PathBuf,
vm_runtime: VmRuntime,
) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
pub async fn publish_module<Abi, Parameters, InstantiationArgument>( &self, chain_id: &ChainId, contract: PathBuf, service: PathBuf, vm_runtime: VmRuntime, ) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
Issues a publishModule GraphQL mutation and returns the new module ID.
Sourcepub async fn query_committees(
&self,
chain_id: &ChainId,
) -> Result<BTreeMap<Epoch, Committee>>
pub async fn query_committees( &self, chain_id: &ChainId, ) -> Result<BTreeMap<Epoch, Committee>>
Queries the committees of the given chain via GraphQL.
Sourcepub async fn events_from_index(
&self,
chain_id: &ChainId,
stream_id: &StreamId,
start_index: u32,
) -> Result<Vec<IndexAndEvent>>
pub async fn events_from_index( &self, chain_id: &ChainId, stream_id: &StreamId, start_index: u32, ) -> Result<Vec<IndexAndEvent>>
Issues an eventsFromIndex GraphQL query for events on the given chain and stream.
Sourcepub async fn query_node(&self, query: impl AsRef<str>) -> Result<Value>
pub async fn query_node(&self, query: impl AsRef<str>) -> Result<Value>
Posts the given GraphQL query to the node service, retrying on timeouts and errors.
Sourcepub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>(
&self,
chain_id: &ChainId,
module_id: &ModuleId<Abi, Parameters, InstantiationArgument>,
parameters: &Parameters,
argument: &InstantiationArgument,
required_application_ids: &[ApplicationId],
) -> Result<ApplicationId<Abi>>
pub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>( &self, chain_id: &ChainId, module_id: &ModuleId<Abi, Parameters, InstantiationArgument>, parameters: &Parameters, argument: &InstantiationArgument, required_application_ids: &[ApplicationId], ) -> Result<ApplicationId<Abi>>
Issues a createApplication GraphQL mutation and returns the new application ID.
Sourcepub async fn chain_tip(
&self,
chain: ChainId,
) -> Result<Option<(CryptoHash, BlockHeight)>>
pub async fn chain_tip( &self, chain: ChainId, ) -> Result<Option<(CryptoHash, BlockHeight)>>
Obtains the hash and height of the chain’s tip block, as known by this node service.
Sourcepub async fn notifications(
&self,
chain_id: ChainId,
) -> Result<Pin<Box<impl Stream<Item = Result<Notification>>>>>
pub async fn notifications( &self, chain_id: ChainId, ) -> Result<Pin<Box<impl Stream<Item = Result<Notification>>>>>
Subscribes to the node service and returns a stream of notifications about a chain.