pub struct NodeService<C>where
C: ClientContext + 'static,{ /* private fields */ }Expand description
The NodeService is a server that exposes a web-server to the client.
The node service is primarily used to explore the state of a chain in GraphQL.
Implementations
Sourceimpl<C> NodeService<C>where
C: ClientContext,
impl<C> NodeService<C>where
C: ClientContext,
Sourcepub fn new(
config: ChainListenerConfig,
port: NonZeroU16,
default_chain: Option<ChainId>,
context: Arc<Mutex<C>>,
read_only: bool,
query_cache_size: Option<usize>,
query_subscriptions: Option<Arc<QuerySubscriptionManager>>,
cancellation_token: CancellationToken,
enable_memory_profiling: bool,
pause: bool,
) -> Self
pub fn new( config: ChainListenerConfig, port: NonZeroU16, default_chain: Option<ChainId>, context: Arc<Mutex<C>>, read_only: bool, query_cache_size: Option<usize>, query_subscriptions: Option<Arc<QuerySubscriptionManager>>, cancellation_token: CancellationToken, enable_memory_profiling: bool, pause: bool, ) -> Self
Creates a new instance of the node service given a client chain and a port.
query_cache_size controls the per-chain LRU cache capacity for application query
responses. Pass None to disable the cache (the default). Enable with
--query-cache-size <N>. Incompatible with --long-lived-services.
Sourcepub fn schema(&self) -> NodeServiceSchema<C>
pub fn schema(&self) -> NodeServiceSchema<C>
Builds the GraphQL schema served by the node service.
Sourcepub async fn run(
self,
cancellation_token: CancellationToken,
command_receiver: UnboundedReceiver<ListenerCommand>,
) -> Result<(), Error>
pub async fn run( self, cancellation_token: CancellationToken, command_receiver: UnboundedReceiver<ListenerCommand>, ) -> Result<(), Error>
Runs the node service.