pub struct Project { /* private fields */ }Expand description
A Linera application project on disk, rooted at a given directory.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn create_new(name: &str, linera_root: Option<&Path>) -> Result<Self>
pub fn create_new(name: &str, linera_root: Option<&Path>) -> Result<Self>
Creates a new application project from the template, scaffolding its files.
Sourcepub fn from_existing_project(root: PathBuf) -> Result<Self>
pub fn from_existing_project(root: PathBuf) -> Result<Self>
Opens an existing application project at the given root directory.