pub enum StoreConfig {
Memory {
config: MemoryStoreConfig,
namespace: String,
genesis_path: PathBuf,
},
StorageService {
config: LruCachingConfig<StorageServiceStoreInternalConfig>,
namespace: String,
},
RocksDb {
config: LruCachingConfig<RocksDbStoreInternalConfig>,
namespace: String,
},
}Expand description
The configuration of the key value store in use.
Variants
Memory
The memory key value store
Fields

config: MemoryStoreConfigThe store configuration.
StorageService
The storage service key-value store
Fields

config: LruCachingConfig<StorageServiceStoreInternalConfig>The store configuration.
RocksDb
The RocksDB key value store
Fields

config: LruCachingConfig<RocksDbStoreInternalConfig>The store configuration.
Implementations
Sourceimpl StoreConfig
impl StoreConfig
Sourcepub async fn run_with_storage<Job>(
self,
wasm_runtime: Option<WasmRuntime>,
allow_application_logs: bool,
cache_sizes: StorageCacheConfig,
job: Job,
) -> Result<<Job as Runnable>::Output, Error>where
Job: Runnable,
pub async fn run_with_storage<Job>(
self,
wasm_runtime: Option<WasmRuntime>,
allow_application_logs: bool,
cache_sizes: StorageCacheConfig,
job: Job,
) -> Result<<Job as Runnable>::Output, Error>where
Job: Runnable,
Connects to the storage backend and runs the given job against it.
Sourcepub async fn run_with_store<Job>(
self,
cache_sizes: StorageCacheConfig,
job: Job,
) -> Result<<Job as RunnableWithStore>::Output, Error>where
Job: RunnableWithStore,
pub async fn run_with_store<Job>(
self,
cache_sizes: StorageCacheConfig,
job: Job,
) -> Result<<Job as RunnableWithStore>::Output, Error>where
Job: RunnableWithStore,
Connects to the key-value store and runs the given store-level job against it.